#[non_exhaustive]pub enum ServiceError {
Exception(ExceptionCode),
InvalidRequest(&'static str),
Internal(&'static str),
}Expand description
Errors returned by a ModbusService handler.
The server maps these to Modbus exception responses on the wire.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exception(ExceptionCode)
A standard Modbus exception (e.g. illegal address, illegal function).
InvalidRequest(&'static str)
The request was malformed or contained invalid parameters.
Internal(&'static str)
An internal error (maps to Server Device Failure exception on the wire).